[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] minor xense tool updates



ChangeSet 1.1726.1.9, 2005/06/23 10:10:00+01:00, smh22@xxxxxxxxxxxxxxxxxxxx

        minor xense tool updates
        
        Signed-off-by: Steven Hand <steven@xxxxxxxxxxxxx>



 policy/policy_tool.c    |   23 +++++++++--------------
 python/xen/xm/create.py |    2 +-
 2 files changed, 10 insertions(+), 15 deletions(-)


diff -Nru a/tools/python/xen/xm/create.py b/tools/python/xen/xm/create.py
--- a/tools/python/xen/xm/create.py     2005-06-23 06:03:07 -04:00
+++ b/tools/python/xen/xm/create.py     2005-06-23 06:03:07 -04:00
@@ -121,7 +121,7 @@
           use="Domain memory in MB.")
 
 gopts.var('ssidref', val='SSIDREF',
-          fn=set_u32, default=0xffffffff,
+          fn=set_u32, default=-1, 
           use="Security Identifier.")
 
 gopts.var('maxmem', val='MEMORY',

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.
diff -Nru a/tools/policy/policy_tool.c b/tools/policy/policy_tool.c
--- a/tools/policy/policy_tool.c        2005-06-23 06:03:07 -04:00
+++ b/tools/policy/policy_tool.c        2005-06-23 06:03:07 -04:00
@@ -14,7 +14,7 @@
  *
  * sHype policy management tool. This code runs in a domain and
  *     manages the Xen security policy by interacting with the
  *     Xen access control module via a /proc/xen/policycmd proc-ioctl, 
  *     which is translated into a policy_op hypercall into Xen.
  * 
  * todo: implement setpolicy to dynamically set a policy cache.
@@ -229,7 +229,6 @@
        default:
                printf("UNKNOWN POLICY!\n");
        }
-       printf("\nPolicy dump End.\n\n");
 }
 
 /*************************** set policy ****************************/
@@ -519,39 +518,35 @@
 int
 main(int argc, char **argv) {
 
-       int policycmd_fd;
+       int policycmd_fd, ret;
 
-       if (argc < 2)
+       if (argc < 2) 
                usage(argv[0]);
                
        if ((policycmd_fd = open("/proc/xen/privcmd", O_RDONLY)) <= 0) {
-                   printf("ERROR: Could not open xen policycmd device!\n");
+                   printf("ERROR: Could not open xen privcmd device!\n");
                    exit(-1);
        }
            
        if (!strcmp(argv[1], "setpolicy")) {
                if (argc != 2)
                        usage(argv[0]);
-               acm_domain_setpolicy(policycmd_fd);
-
+               ret = acm_domain_setpolicy(policycmd_fd);
        } else if (!strcmp(argv[1], "getpolicy")) {
                if (argc != 2)
                        usage(argv[0]);
-               acm_domain_getpolicy(policycmd_fd);
-
+               ret = acm_domain_getpolicy(policycmd_fd);
        } else if (!strcmp(argv[1], "loadpolicy")) {
                if (argc != 3) 
                        usage(argv[0]);
-               acm_domain_loadpolicy(policycmd_fd, argv[2]);
-
+               ret = acm_domain_loadpolicy(policycmd_fd, argv[2]);
        } else if (!strcmp(argv[1], "dumpstats")) {
                if (argc != 2) 
                        usage(argv[0]);
-               acm_domain_dumpstats(policycmd_fd);
-
+               ret = acm_domain_dumpstats(policycmd_fd);
        } else
                usage(argv[0]);
 
        close(policycmd_fd);
-       return 0;
+       return ret;
 }
@@ -14,7 +14,7 @@
  * sHype policy management tool. This code runs in a domain and
  *     manages the Xen security policy by interacting with the
- *     Xen access control module via a /proc/xen/policycmd proc-ioctl, 
+ *     Xen access control module via a /proc/xen/privcmd proc-ioctl, 
  *     which is translated into a policy_op hypercall into Xen.
  * 